// Wait for DOM to be fully loaded
document.addEventListener('DOMContentLoaded', function() {

    // RSVP Form Handling
    const form = document.getElementById('rsvpForm');
    if (form) {
        const submitBtn = form.querySelector('.submit-btn');
        const formFields = form.querySelectorAll('.field');
        const plusOneSection = document.getElementById('plusOneSection');
        const hasPlusOneCheckbox = document.getElementById('hasPlusOne');

        // Handle Plus One Toggle
        if (hasPlusOneCheckbox) {
            hasPlusOneCheckbox.addEventListener('change', function() {
                plusOneSection.style.display = this.checked ? 'block' : 'none';
                const plusOneInputs = plusOneSection.querySelectorAll('input');
                plusOneInputs.forEach(input => {
                    input.required = this.checked;
                });
            });
        }

        // Form Validation
        function validateForm() {
            let isValid = true;
            const email = form.querySelector('input[type="email"]');
            const phone = form.querySelector('input[type="tel"]');

            // Check required fields
            formFields.forEach(field => {
                const input = field.querySelector('input');
                if (input && input.required && !input.value.trim()) {
                    isValid = false;
                    field.classList.add('error');
                } else {
                    field.classList.remove('error');
                }
            });

            // Validate email format
            if (email && email.value) {
                const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
                if (!emailRegex.test(email.value)) {
                    isValid = false;
                    email.parentElement.classList.add('error');
                }
            }

            // Validate phone format (if provided)
            if (phone && phone.value) {
                const phoneRegex = /^\+?[\d\s-]{10,}$/;
                if (!phoneRegex.test(phone.value)) {
                    isValid = false;
                    phone.parentElement.classList.add('error');
                }
            }

            return isValid;
        }

        // Form Submission
        form.addEventListener('submit', async function(e) {
            // Prevent the default form submission behavior
            e.preventDefault();
            console.log('Form submission intercepted');

            if (!validateForm()) {
                return;
            }

            // Disable submit button and show loading state
            submitBtn.disabled = true;
            submitBtn.innerHTML = '<span class="loading"></span> Sending...';

            try {
                // Create a data object from the form
                const formData = new FormData(form);
                const data = {};
                
                // Convert FormData to a regular object
                for (let [key, value] of formData.entries()) {
                    data[key] = value;
                }
                
                // Log the data for debugging
                console.log('Sending data:', data);
                
                // Send the data using fetch with proper headers
                const response = await fetch('save_rsvp.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'Accept': 'application/json'
                    },
                    body: JSON.stringify(data)
                });

                // Check if the response is JSON
                const contentType = response.headers.get('content-type');
                if (contentType && contentType.includes('application/json')) {
                    const result = await response.json();
                    console.log('Server response:', result);
                    
                    if (result.success) {
                        // Show success message
                        form.innerHTML = `
                            <div class="success-message">
                                <h3>Thank You!</h3>
                                <p>Your RSVP has been received successfully.</p>
                            </div>
                        `;
                    } else {
                        throw new Error(result.message || 'Failed to submit RSVP');
                    }
                } else {
                    // Handle non-JSON response
                    const text = await response.text();
                    console.error('Non-JSON response:', text);
                    throw new Error('Server returned an invalid response format');
                }
            } catch (error) {
                console.error('Form submission error:', error);
                
                // Show error message
                const errorDiv = document.createElement('div');
                errorDiv.className = 'error-message';
                errorDiv.textContent = 'Sorry, there was an error submitting your RSVP. Please try again.';
                form.insertBefore(errorDiv, submitBtn);
                
                // Reset submit button
                submitBtn.disabled = false;
                submitBtn.textContent = 'Submit RSVP';
            }
        });

        // Real-time validation
        formFields.forEach(field => {
            const input = field.querySelector('input');
            if (input) {
                input.addEventListener('input', function() {
                    field.classList.remove('error');
                    const errorMessage = field.querySelector('.error-message');
                    if (errorMessage) {
                        errorMessage.remove();
                    }
                });
            }
        });
    }
}); 